@@ -34,6 +34,12 @@ smart.install.packages(package="snowfall", mirror=repo.cran)
 smart.install.packages(package="sm", mirror=repo.cran)
 smart.install.packages(package="rda", mirror=repo.cran)
 smart.install.packages(package="flexmix", mirror=repo.cran) ## required by WECCA
+smart.install.packages(package="MKmisc", mirror=repo.cran)
+smart.install.packages(package="multicore", mirror=repo.cran) # required by zinba
+smart.install.packages(package="doMC", mirror=repo.cran) # required by zinba
+smart.install.packages(package="foreach", mirror=repo.cran) # required by zinba
+smart.install.packages(package="quantreg", mirror=repo.cran) # required by zinba
+smart.install.packages(package="R.utils", mirror=repo.cran) # required by zinba
 
 
 # Install packages, and their dependencies, from Bioconductor
@@ -99,7 +105,6 @@ smart.install.packages(bioconductor.package="safe", mirror=repo.bioc)
 smart.install.packages(bioconductor.package="CGHbase", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="CGHcall", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="CGHregions", mirror=repo.bioc) 
-smart.install.packages(bioconductor.package="CGHregions", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="DNAcopy", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="MLInterfaces", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="MEDIPS", mirror=repo.bioc) 
@@ -124,23 +129,37 @@ smart.install.packages(bioconductor.package="edgeR", mirror=repo.bioc)
 smart.install.packages(bioconductor.package="rtracklayer", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="maSigPro", mirror=repo.bioc) 
 smart.install.packages(bioconductor.package="qvalue", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="DESeq", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="RPA", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="methylumi", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="IlluminaHumanMethylation450k.db", mirror=repo.bioc) # annotation package, not needed if all annotation packages from the repository are installed
+smart.install.packages(bioconductor.package="IlluminaHumanMethylation27k.db", mirror=repo.bioc) # annotation package, not needed if all annotation packages from the repository are installed
+smart.install.packages(bioconductor.package="VariantAnnotation", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="TxDb.Hsapiens.UCSC.hg19.knownGene", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="DEXSeq", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="BSgenome.Hsapiens.UCSC.hg19", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="rich", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="BiodiversityR", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="pegas", mirror=repo.bioc)
+smart.install.packages(bioconductor.package="labdsv", mirror=repo.bioc)
 
 
 # Install non-repo packages
-smart.install.packages(url.package="http://www.few.vu.nl/~mavdwiel/NoWaves/NoWaves_0.4.tar.gz")
+smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/NoWaves_0.4.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/FruitFlyAgilent.db.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/hgug4851a.db.tar.gz")
-smart.install.packages(url.package="http://www.few.vu.nl/~mavdwiel/CGHtest/CGHtest_1.1.tar.gz")
-smart.install.packages(url.package="http://www.few.vu.nl/~mavdwiel/CGHtest/CGHtestpar_0.0.tar.gz")
+smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/CGHtest_1.1.tar.gz")
+smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/CGHtestpar_0.0.tar.gz")
 smart.install.packages(url.package="http://addictedtor.free.fr/packages/fpc_1.1-5.tar.gz")
 smart.install.packages(url.package="http://www.math.utu.fi/projects/software/bio/ROTS_1.1.1.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/A2R_0.0-4.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/exon.pmcdf_1.1.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/mouseexonpmcdf_1.1.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/ratexonpmcdf_1.1.tar.gz")
-smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/intCNGEan_0.53.tar.gz")
+smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/intCNGEan_0.54.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/CORNA_1.2.tar.gz")
 smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/WECCA_0.30.tar.gz")
+smart.install.packages(url.package="http://www.nic.funet.fi/pub/sci/molbio/chipster/dist/tools_extras/R_libraries/zinba_2.02.03.tar.gz")
 
 
 # Install the whole annotation repository from Bioconductor
