@@ -1,4 +1,4 @@
-# TOOL annotate-variant.R: "Annotate variants" (Annotate variants listed in a VCF file using the Bioconductor package VariantAnotation.)
+# TOOL annotate-variant.R: "Annotate variants" (Annotate variants listed in a VCF file using the Bioconductor package VariantAnnotation. Coding, UTR, intronic and promoter variants are annotated, intergenic variants are ignored.)
 # INPUT input.vcf: "Sorted or unsorted VCF file" TYPE GENERIC
 # OUTPUT all-variants.tsv
 # OUTPUT coding-variants.tsv
@@ -6,6 +6,7 @@
 
 
 # 31.8.2012 JTT
+# 15.11.2012 Uses VariantAnnotation package 1.4.3. JTT,EK 
 
 #input.vcf<-system.file("extdata", "chr22.vcf.gz", package="VariantAnnotation")
 #input.vcf<-"var.flt2.vcf"
@@ -19,15 +20,18 @@ vcf<-readVcf("input.vcf", genome)
 
 # Correct the chromosome names 
 #vcf@rowData@seqnames@values
+newnames<-c("1"="chr1", "2"="chr2", "3"="chr3", "4"="chr4", "5"="chr5", "6"="chr6", "7"="chr7", "8"="chr8", "9"="chr9", "10"="chr10",
+                                     "11"="chr11", "12"="chr12", "13"="chr13", "14"="chr14", "15"="chr15", "16"="chr16", "17"="chr17", "18"="chr18", "19"="chr19", "20"="chr20",
+                                     "21"="chr21", "22"="chr22", "Y"="chrY", "X"="chrX")
 if(length(grep("chr", vcf@rowData@seqnames@values))>=1) {
    vcf2<-vcf
+   rd<-rowData(vcf)
 } else {
    #vcf@rowData@seqnames@values<-paste("chr", vcf@rowData@seqnames@values, sep="")
-   vcf2<-vcf
    if(genome=="hg19") {
-      vcf2 <- renameSeqlevels(vcf, c("1"="chr1", "2"="chr2", "3"="chr3", "4"="chr4", "5"="chr5", "6"="chr6", "7"="chr7", "8"="chr8", "9"="chr9", "10"="chr10",
-                                     "11"="chr11", "12"="chr12", "13"="chr13", "14"="chr14", "15"="chr15", "16"="chr16", "17"="chr17", "18"="chr18", "19"="chr19", "20"="chr20",
-                                     "21"="chr21", "22"="chr22", "Y"="chrY", "X"="chrX"))
+      vcf2 <- renameSeqlevels(vcf, newnames)
+      rd<-rowData(vcf)
+      rd2  <- renameSeqlevels(rd, newnames)
    }
 }
 
@@ -42,8 +46,16 @@ txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene
 # spl<-locateVariants(rd, txdb, SpliceSiteVariants())
 
 # Locate all variants
-rd<-rowData(vcf2)
-allvar <- locateVariants(rd, txdb, AllVariants())
+codvar <- locateVariants(vcf2, txdb, CodingVariants())
+intvar <- locateVariants(vcf2, txdb, IntronVariants())
+utr5var <- locateVariants(vcf2, txdb, FiveUTRVariants())
+utr3var <- locateVariants(vcf2, txdb, ThreeUTRVariants())
+#intgvar <- locateVariants(vcf2, txdb, IntergenicVariants())
+spsgvar <- locateVariants(vcf2, txdb, SpliceSiteVariants())
+promvar <- locateVariants(vcf2, txdb, PromoterVariants())
+allvar<-c(codvar, intvar, utr5var, utr3var, spsgvar, promvar)
+#rd<-rowData(vcf2)
+#allvar <- locateVariants(rd, txdb, AllVariants())
 allvar2<-as.data.frame(allvar)
 colnames(allvar2)<-toupper(colnames(allvar2))
 
@@ -79,4 +91,4 @@ cod34<-merge(cod33, ensg, by.x="geneID", by.y="ENTREZID", all.x=TRUE)
 
 # Write results to disk
 write.table(allvar3, "all-variants.tsv", col.names=T, row.names=F, sep="\t", quote=FALSE)
-write.table(cod34, "coding-variants.tsv", col.names=T, row.names=F, sep="\t", quote=FALSE)
+write.table(cod34, "coding-variants.tsv", col.names=T, row.names=F, sep="\t", quote=FALSE)
\ No newline at end of file
