@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2006, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,11 +27,13 @@
  * ---------------------------
  * DefaultDrawingSupplier.java
  * ---------------------------
- * (C) Copyright 2003-2007, by Object Refinery Limited.
+ * (C) Copyright 2003-2006, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Jeremy Bowman;
  *
+ * $Id: DefaultDrawingSupplier.java,v 1.6.2.2 2006/08/01 15:03:04 mungady Exp $
+ *
  * Changes
  * -------
  * 16-Jan-2003 : Version 1 (DG);
@@ -41,8 +43,6 @@
  *               contributed by Jeremy Bowman (DG);
  * 25-Mar-2003 : Implemented Serializable (DG);
  * 20-Aug-2003 : Implemented Cloneable and PublicCloneable (DG);
- * ------------- JFREECHART 1.0.x ---------------------------------------------
- * 13-Jun-2007 : Added fillPaintSequence (DG);
  *
  */
 
@@ -72,8 +72,8 @@ import org.jfree.util.ShapeUtilities;
  * {@link Plot} instances have a new instance of this class installed by 
  * default.
  */
-public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable, 
-        PublicCloneable, Serializable {
+public class DefaultDrawingSupplier 
+        implements DrawingSupplier, Cloneable, PublicCloneable, Serializable {
 
     /** For serialization. */
     private static final long serialVersionUID = -7339847061039422538L;
@@ -86,10 +86,6 @@ public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable,
     public static final Paint[] DEFAULT_OUTLINE_PAINT_SEQUENCE = new Paint[] {
             Color.lightGray};
 
-    /** The default fill paint sequence. */
-    public static final Paint[] DEFAULT_FILL_PAINT_SEQUENCE = new Paint[] {
-            Color.white};
-
     /** The default stroke sequence. */
     public static final Stroke[] DEFAULT_STROKE_SEQUENCE = new Stroke[] {
             new BasicStroke(1.0f, BasicStroke.CAP_SQUARE, 
@@ -116,12 +112,6 @@ public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable,
     /** The current outline paint index. */
     private int outlinePaintIndex;
 
-    /** The fill paint sequence. */
-    private transient Paint[] fillPaintSequence;
-
-    /** The current fill paint index. */
-    private int fillPaintIndex;
-
     /** The stroke sequence. */
     private transient Stroke[] strokeSequence;
 
@@ -146,7 +136,7 @@ public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable,
      */
     public DefaultDrawingSupplier() {
 
-        this(DEFAULT_PAINT_SEQUENCE, DEFAULT_FILL_PAINT_SEQUENCE,
+        this(DEFAULT_PAINT_SEQUENCE,
              DEFAULT_OUTLINE_PAINT_SEQUENCE,
              DEFAULT_STROKE_SEQUENCE,
              DEFAULT_OUTLINE_STROKE_SEQUENCE,
@@ -170,7 +160,6 @@ public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable,
                                   Shape[] shapeSequence) {
 
         this.paintSequence = paintSequence;
-        this.fillPaintSequence = DEFAULT_FILL_PAINT_SEQUENCE;
         this.outlinePaintSequence = outlinePaintSequence;
         this.strokeSequence = strokeSequence;
         this.outlineStrokeSequence = outlineStrokeSequence;
@@ -178,31 +167,6 @@ public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable,
 
     }
 
-    /**
-     * Creates a new supplier.
-     *
-     * @param paintSequence  the paint sequence.
-     * @param fillPaintSequence  the fill paint sequence.
-     * @param outlinePaintSequence  the outline paint sequence.
-     * @param strokeSequence  the stroke sequence.
-     * @param outlineStrokeSequence  the outline stroke sequence.
-     * @param shapeSequence  the shape sequence.
-     * 
-     * @since 1.0.6
-     */
-    public DefaultDrawingSupplier(Paint[] paintSequence, 
-            Paint[] fillPaintSequence, Paint[] outlinePaintSequence,
-            Stroke[] strokeSequence, Stroke[] outlineStrokeSequence,
-            Shape[] shapeSequence) {
-
-        this.paintSequence = paintSequence;
-        this.fillPaintSequence = fillPaintSequence;
-        this.outlinePaintSequence = outlinePaintSequence;
-        this.strokeSequence = strokeSequence;
-        this.outlineStrokeSequence = outlineStrokeSequence;
-        this.shapeSequence = shapeSequence;
-    }
-
     /**
      * Returns the next paint in the sequence.
      *
@@ -227,20 +191,6 @@ public class DefaultDrawingSupplier implements DrawingSupplier, Cloneable,
         return result;
     }
 
-    /**
-     * Returns the next fill paint in the sequence.
-     *
-     * @return The paint.
-     * 
-     * @since 1.0.6
-     */
-    public Paint getNextFillPaint() {
-        Paint result = this.fillPaintSequence[this.fillPaintIndex 
-                % this.fillPaintSequence.length];
-        this.fillPaintIndex++;
-        return result;
-    }
-
     /**
      * Returns the next stroke in the sequence.
      *
